package services

import (
	"errors"
	"fmt"
	"hongze/hongze_clpt/models"
	"hongze/hongze_clpt/utils"
	"strconv"
	"strings"
	"time"
)

func GetResourceDataList(condition string, pars []interface{}, startSize, pageSize int, user *models.WxUserItem) (items []*models.CygxResourceDataResp, err error) {

	uid := user.UserId
	list, e := models.GetResourceDataList(condition, pars, startSize, pageSize)
	if e != nil {
		err = errors.New("GetResourceDataList, Err: " + e.Error())
		return
	}
	mapItems := make(map[string]*models.CygxResourceDataResp)
	for _, v := range list {
		//预处理文章
		item := new(models.CygxResourceDataResp)
		item.Id = v.Id
		item.SourceId = v.SourceId
		item.Source = v.Source
		item.Title = v.Title
		item.Annotation = v.Annotation
		item.Abstract = v.Abstract
		item.PublishDate = utils.TimeRemoveHms2(v.PublishDate)
		mapItems[fmt.Sprint(v.Source, v.SourceId)] = item
	}

	var articleIds []int
	var newchartIds []int
	var roadshowIds []int
	var activityIds []int
	var activityvideoIds []int
	var activityvoiceIds []int
	var activityspecialIds []int

	//Source      string    `description:"资源类型 报告 ：article 、图表 ：newchart、微路演 ：roadshow、活动 ：activity、活动视频：activityvideo、活动音频：activityvoice、专项调研活动：activityspecial"`
	for _, v := range list {
		if v.Source == "article" {
			articleIds = append(articleIds, v.SourceId)
		} else if v.Source == "newchart" {
			newchartIds = append(newchartIds, v.SourceId)
		} else if v.Source == "roadshow" {
			roadshowIds = append(roadshowIds, v.SourceId)
		} else if v.Source == "activity" {
			activityIds = append(activityIds, v.SourceId)
		} else if v.Source == "activityvideo" {
			activityvideoIds = append(activityvideoIds, v.SourceId)
		} else if v.Source == "activityvoice" {
			activityvoiceIds = append(activityvoiceIds, v.SourceId)
		} else if v.Source == "activityspecial" {
			activityspecialIds = append(activityspecialIds, v.SourceId)
		}
	}
	detail, e := models.GetConfigByCode("city_img_url")
	if e != nil {
		err = errors.New("GetResourceDataList, Err: " + e.Error())
		return
	}
	detailChart, e := models.GetConfigByCode("chart_img_url")
	if e != nil {
		err = errors.New("GetResourceDataList, Err: " + e.Error())
		return
	}
	addressList := strings.Split(detail.ConfigValue, "{|}")
	mapAddress := make(map[string]string)
	chartList := strings.Split(detailChart.ConfigValue, "{|}")
	mapChart := make(map[string]string)
	var cityName string
	var chartName string
	var imgUrl string
	var imgUrlChart string
	for _, v := range addressList {
		vslice := strings.Split(v, "_")
		cityName = vslice[0]
		imgUrl = vslice[len(vslice)-1]
		mapAddress[cityName] = imgUrl
	}
	for _, v := range chartList {
		vslice := strings.Split(v, "_")
		chartName = vslice[0]
		imgUrlChart = vslice[len(vslice)-1]
		mapChart[chartName] = imgUrlChart
	}
	var imgUrlResp string

	//处理文章
	if len(articleIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND a.article_id IN (` + utils.GetOrmInReplace(len(articleIds)) + `)`
		pars = append(pars, articleIds)
		articleList, e := models.GetHomeListPublic(condition, pars, 0, len(articleIds))
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}

		articleList, e = HandleArticleCategoryImg(articleList, user)
		if e != nil {
			err = errors.New("HandleArticleCategoryImg, Err: " + e.Error())
			return
		}
		for _, v := range articleList {
			mapItems[fmt.Sprint("article", v.ArticleId)].Title = v.Title
			mapItems[fmt.Sprint("article", v.ArticleId)].Annotation = v.Annotation
			mapItems[fmt.Sprint("article", v.ArticleId)].Abstract = v.Abstract
			mapItems[fmt.Sprint("article", v.ArticleId)].PublishDate = v.PublishDate
			mapItems[fmt.Sprint("article", v.ArticleId)].Pv = v.Pv
			mapItems[fmt.Sprint("article", v.ArticleId)].IsResearch = v.IsResearch
			mapItems[fmt.Sprint("article", v.ArticleId)].BodyImg = v.BodyImg
		}
	}

	//处理活动
	if len(activityIds) > 0 {
		for _, vss := range activityIds {
			imgUrlResp += strconv.Itoa(vss) + ","
		}
		pars = make([]interface{}, 0)
		condition = ` AND art.activity_id IN (` + utils.GetOrmInReplace(len(activityIds)) + `)   `
		pars = append(pars, activityIds)
		activityList, e := models.GetActivityListNew(condition, pars, uid, 0, len(activityIds), 0, 0, "")
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}
		var activityListRersp []*models.ActivityListResp
		for _, v := range activityList {
			activityListRersp = append(activityListRersp, ActivityButtonShow(v, user))
		}
		//处理不同的报名方式按钮回显
		mapActivitySignup, e := GetActivitySignupResp(activityIds, user)
		if e != nil {
			err = errors.New("GetActivitySignupResp, Err: " + e.Error())
			return
		}
		for _, v := range activityListRersp {
			if v == nil {
				continue
			}
			if v.ActivityType == 0 {
				if mapAddress[v.City] != "" {
					imgUrlResp = mapAddress[v.City]
				} else {
					imgUrlResp = mapAddress["其它"]
				}
			} else {
				if mapChart[v.ChartPermissionName] != "" {
					imgUrlResp = mapChart[v.ChartPermissionName]
				}
			}
			mapItems[fmt.Sprint("activity", v.ActivityId)].Title = v.ActivityName
			mapItems[fmt.Sprint("activity", v.ActivityId)].City = v.City
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsSignup = v.IsSignup
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsCancelMeetingReminder = v.IsCancelMeetingReminder
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsAppointment = v.IsAppointment
			mapItems[fmt.Sprint("activity", v.ActivityId)].ActiveState = v.ActiveState
			mapItems[fmt.Sprint("activity", v.ActivityId)].ImgUrlText = v.ImgUrlText
			mapItems[fmt.Sprint("activity", v.ActivityId)].ActivityType = v.ActivityType
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsShowOutboundCall = v.IsShowOutboundCall
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsShowMeetingReminder = v.IsShowMeetingReminder
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsShowHelpSsk = v.IsShowHelpSsk
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsShowSignup = v.IsShowSignup
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsShowAppointment = v.IsShowAppointment
			mapItems[fmt.Sprint("activity", v.ActivityId)].IsShowDetails = v.IsShowDetails
			mapItems[fmt.Sprint("activity", v.ActivityId)].ActivityTimeText = v.ActivityTimeText
			mapItems[fmt.Sprint("activity", v.ActivityId)].Expert = v.Expert
			mapItems[fmt.Sprint("activity", v.ActivityId)].Speaker = v.Speaker
			mapItems[fmt.Sprint("activity", v.ActivityId)].DistinguishedGuest = v.DistinguishedGuest
			mapItems[fmt.Sprint("activity", v.ActivityId)].YidongActivityUrl = v.YidongActivityUrl
			mapItems[fmt.Sprint("activity", v.ActivityId)].ImgUrl = imgUrlResp
			mapItems[fmt.Sprint("activity", v.ActivityId)].SignupType = mapActivitySignup[v.ActivityId]
			mapItems[fmt.Sprint("activity", v.ActivityId)].ActivityTypeId = v.ActivityTypeId
		}
	}

	//处理图表
	if len(newchartIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND a.chart_id IN (` + utils.GetOrmInReplace(len(newchartIds)) + `)`
		pars = append(pars, newchartIds)
		chartDateList, e := models.GetChartListCollection(condition, pars, uid, 0, len(newchartIds))
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}
		for _, v := range chartDateList {
			mapItems[fmt.Sprint("newchart", v.ChartId)].Title = v.Title
			mapItems[fmt.Sprint("newchart", v.ChartId)].ImgUrl = v.BodyHtml
			mapItems[fmt.Sprint("newchart", v.ChartId)].IsTop = v.IsTop
		}
	}

	//处理专项调研
	if len(activityspecialIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND art.activity_id IN (` + utils.GetOrmInReplace(len(activityspecialIds)) + `)`
		pars = append(pars, activityspecialIds)
		activitySpeciallist, e := models.GetCygxActivitySpecialDetailList(condition, pars, user.UserId, 0, len(activityspecialIds))
		if e != nil {
			err = errors.New("GetCygxActivitySpecialDetailList, Err: " + e.Error())
			return
		}
		UserMap, e := GetSpecialTripUserMap(activityspecialIds, user.UserId)
		if e != nil {
			err = errors.New("GetSpecialTripUserMap, Err: " + e.Error())
			return
		}
		for _, v := range activitySpeciallist {
			if mapChart[v.ChartPermissionName] != "" {
				imgUrlResp = mapChart[v.ChartPermissionName]
			}
			if _, ok := UserMap[v.ActivityId]; ok {
				mapItems[fmt.Sprint("activityspecial", v.ActivityId)].IsTrip = 1
			}
			if v.Days == 0 {
				mapItems[fmt.Sprint("activityspecial", v.ActivityId)].TripStatus = 1
				mapItems[fmt.Sprint("activityspecial", v.ActivityId)].TripImgLink = v.TripImgLink
				mapItems[fmt.Sprint("activityspecial", v.ActivityId)].ActivityTimeText = v.ActivityTimeText
			} else {
				mapItems[fmt.Sprint("activityspecial", v.ActivityId)].TripStatus = 2
				mapItems[fmt.Sprint("activityspecial", v.ActivityId)].TripImgLink = v.TripImgLinkFix
				mapItems[fmt.Sprint("activityspecial", v.ActivityId)].ActivityTimeText = v.ActivityTimeTextByDay
				resultTimeStart := utils.StrTimeToTime(v.ActivityTime)  //时间字符串格式转时间格式
				resultTimeEnd := utils.StrTimeToTime(v.ActivityTimeEnd) //时间字符串格式转时间格式
				if resultTimeStart.After(time.Now()) {
					mapItems[fmt.Sprint("activityspecial", v.ActivityId)].ActiveState = strconv.Itoa(1)
				} else if time.Now().After(resultTimeEnd) {
					mapItems[fmt.Sprint("activityspecial", v.ActivityId)].ActiveState = strconv.Itoa(3)
				} else {
					mapItems[fmt.Sprint("activityspecial", v.ActivityId)].ActiveState = strconv.Itoa(2)
				}
			}
			mapItems[fmt.Sprint("activityspecial", v.ActivityId)].Title = v.ResearchTheme
			mapItems[fmt.Sprint("activityspecial", v.ActivityId)].ActivityType = v.SpecialType
			mapItems[fmt.Sprint("activityspecial", v.ActivityId)].City = v.City
			mapItems[fmt.Sprint("activityspecial", v.ActivityId)].ActivityTime = v.ActivityTime
			mapItems[fmt.Sprint("activityspecial", v.ActivityId)].IsSignup = v.IsSignup
			mapItems[fmt.Sprint("activityspecial", v.ActivityId)].ImgUrl = imgUrlResp
		}
	}

	//处理路演
	if len(roadshowIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND video_id IN (` + utils.GetOrmInReplace(len(roadshowIds)) + `)`
		pars = append(pars, roadshowIds)
		roadshowVideoList, e := models.GetMicroRoadshowVideoListBycondition(condition, pars, 0, len(roadshowIds))
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}
		for _, v := range roadshowVideoList {
			mapItems[fmt.Sprint("roadshow", v.VideoId)].Title = v.VideoName
			mapItems[fmt.Sprint("roadshow", v.VideoId)].ImgUrl = v.ImgUrl
			mapItems[fmt.Sprint("roadshow", v.VideoId)].PublishDate = v.CreateTime.Format(utils.FormatDateTime)
		}
	}
	//处理路活动视频
	if len(activityvideoIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND video_id IN (` + utils.GetOrmInReplace(len(activityvideoIds)) + `)`
		pars = append(pars, activityvideoIds)
		activityVideoList, e := models.GetActivityVideoList(condition, pars, 0, len(activityvideoIds))
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}
		//// 获取默认图配置
		_, videoMap, _, _, e := GetMicroRoadShowDefaultImgConfig()
		if e != nil {
			err = errors.New("GetMicroRoadShowDefaultImgConfig, Err: " + e.Error())
			return
		}
		for _, v := range activityVideoList {
			mapItems[fmt.Sprint("activityvideo", v.VideoId)].Title = v.VideoName
			mapItems[fmt.Sprint("activityvideo", v.VideoId)].ImgUrl = videoMap[v.ChartPermissionId]
			mapItems[fmt.Sprint("activityvideo", v.VideoId)].ChartPermissionId = v.ChartPermissionId
		}
	}

	//处理路活音频
	if len(activityvoiceIds) > 0 {
		pars = make([]interface{}, 0)
		condition = ` AND activity_voice_id IN (` + utils.GetOrmInReplace(len(activityvoiceIds)) + `)`
		pars = append(pars, activityvoiceIds)
		activityVoiceList, e := models.GetActivityVoiceList(condition, pars, 0, len(activityvoiceIds))
		if e != nil {
			err = errors.New("GetResourceDataList, Err: " + e.Error())
			return
		}

		// 用户权限
		authInfo, permissionArr, e := GetUserRaiPermissionInfo(user.UserId, user.CompanyId)
		if e != nil {
			err = errors.New("GetUserRaiPermissionInfo, Err: " + e.Error())
			return
		}

		// 获取默认图配置
		audioMap, _, _, _, e := GetMicroRoadShowDefaultImgConfig()
		if e != nil {
			err = errors.New("GetMicroRoadShowDefaultImgConfig, Err: " + e.Error())
			return
		}
		for i, v := range activityVoiceList {
			au := new(models.UserPermissionAuthInfo)
			au.SellerName = authInfo.SellerName
			au.SellerMobile = authInfo.SellerMobile
			au.HasPermission = authInfo.HasPermission
			au.OperationMode = authInfo.OperationMode
			if au.HasPermission == 1 {
				// 非宏观权限进一步判断是否有权限
				if activityVoiceList[i].ChartPermissionId != utils.HONG_GUAN_ID && !utils.InArrayByStr(permissionArr, activityVoiceList[i].ChartPermissionName) {
					au.HasPermission = 2
				}
			}
			// 无权限的弹框提示
			if au.HasPermission != 1 {
				if au.OperationMode == UserPermissionOperationModeCall {
					au.PopupMsg = UserPermissionPopupMsgCallActivity
				} else {
					au.PopupMsg = UserPermissionPopupMsgApplyActivity
				}
			}
			mapItems[fmt.Sprint("activityvoice", v.ActivityVoiceId)].AuthInfo = au
			mapItems[fmt.Sprint("activityvoice", v.ActivityVoiceId)].Title = v.VoiceName
			mapItems[fmt.Sprint("activityvoice", v.ActivityVoiceId)].ImgUrl = audioMap[v.ChartPermissionId]
			if au.HasPermission == 1 {
				mapItems[fmt.Sprint("activityvoice", v.ActivityVoiceId)].ResourceUrl = v.VoiceUrl
			}
		}
	}
	for _, vList := range list {
		for _, v := range mapItems {
			if v.SourceId == vList.SourceId {
				items = append(items, v)
			}
		}
	}
	return
}
